Documentation
¶
Index ¶
- Constants
- func Factory(ctx context.Context, conf *logical.BackendConfig) (logical.Backend, error)
- func IsNatsUrl(url string) bool
- type AccountResolverAction
- type AccountServerStatus
- type CredsData
- type CredsParameters
- type CredsStorage
- type IssueAccountData
- type IssueAccountParameters
- type IssueAccountStatus
- type IssueAccountStorage
- type IssueOperatorData
- type IssueOperatorParameters
- type IssueOperatorStatus
- type IssueOperatorStorage
- type IssueStatus
- type IssueUserData
- type IssueUserParameters
- type IssueUserStatus
- type IssueUserStorage
- type JWTData
- type JWTParameters
- type JWTStorage
- type NKeyStorage
- type NatsBackend
- type NatsClient
- type NkeyData
- type NkeyParameters
Constants ¶
const ( // DefaultSysAccountName is the name of the system account DefaultSysAccountName = "sys" // DefaultSysUser is the name of the system user DefaultPushUser = "default-push" )
const ( // Parameters InvalidParametersError = "invalid parameters" DecodeFailedError = "could not decode parameters" // ISSUE AddingIssueFailedError = "adding issue failed" ReadingIssueFailedError = "reading issue failed" IssueNotFoundError = "issue not found" DeleteIssueFailedError = "deleting issue failed" ListIssuesFailedError = "listing issues failed" // JWT AddingJWTFailedError = "adding jwt failed" ReadingJWTFailedError = "reading jwt failed" ListJWTsFailedError = "listing jwts failed" DeleteJWTFailedError = "deleting jwt failed" JwtNotFoundError = "jwt not found" // NKEY AddingNkeyFailedError = "adding nkey failed" ReadingNkeyFailedError = "reading nkey failed" ListNkeysFailedError = "listing nkeys failed" DeleteNkeyFailedError = "deleting nkey failed" NkeyNotFoundError = "nkey not found" // CREDS AddingCredsFailedError = "adding creds failed" ReadingCredsFailedError = "reading creds failed" ListCredsFailedError = "listing credss failed" DeleteCredsFailedError = "deleting creds failed" CredsNotFoundError = "creds not found" )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type AccountResolverAction ¶ added in v1.5.0
type AccountResolverAction string
const ( AccountResolverActionPush AccountResolverAction = "push" AccountResolverActionDelete AccountResolverAction = "delete" )
type AccountServerStatus ¶
type CredsData ¶
type CredsData struct {
CredsStorage
}
CredsData represents the the data returned by a Creds operation
type CredsParameters ¶
type CredsParameters struct {
Operator string `json:"operator,omitempty"`
Account string `json:"account,omitempty"`
User string `json:"user,omitempty"`
CredsStorage
}
CredsParameters represents the parameters for a Creds operation
type CredsStorage ¶
type CredsStorage struct {
Creds string `json:"creds"`
}
JWTStorage represents a Creds stored in the backend
type IssueAccountData ¶
type IssueAccountData struct {
Operator string `json:"operator"`
Account string `json:"account"`
UseSigningKey string `json:"useSigningKey"`
Claims v1alpha1.AccountClaims `json:"claims"`
Status IssueAccountStatus `json:"status"`
}
type IssueAccountParameters ¶
type IssueAccountParameters struct {
Operator string `json:"operator"`
Account string `json:"account"`
UseSigningKey string `json:"useSigningKey,omitempty"`
Claims v1alpha1.AccountClaims `json:"claims,omitempty"`
}
IssueAccountParameters is the user facing interface for configuring an account issue. Using pascal case on purpose. +k8s:deepcopy-gen=true
func (*IssueAccountParameters) DeepCopy ¶
func (in *IssueAccountParameters) DeepCopy() *IssueAccountParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IssueAccountParameters.
func (*IssueAccountParameters) DeepCopyInto ¶
func (in *IssueAccountParameters) DeepCopyInto(out *IssueAccountParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IssueAccountStatus ¶
type IssueAccountStatus struct {
Account IssueStatus `json:"account"`
AccountServer AccountServerStatus `json:"accountServer"`
}
type IssueAccountStorage ¶
type IssueAccountStorage struct {
Operator string `json:"operator"`
Account string `json:"account"`
UseSigningKey string `json:"useSigningKey"`
Claims v1alpha1.AccountClaims `json:"claims"`
Status IssueAccountStatus `json:"status"`
}
type IssueOperatorData ¶
type IssueOperatorData struct {
Operator string `json:"operator"`
CreateSystemAccount bool `json:"createSystemAccount"`
SyncAccountServer bool `json:"syncAccountServer"`
Claims operatorv1.OperatorClaims `json:"claims"`
Status IssueOperatorStatus `json:"status"`
}
type IssueOperatorParameters ¶
type IssueOperatorParameters struct {
Operator string `json:"operator"`
CreateSystemAccount bool `json:"createSystemAccount,omitempty"`
SyncAccountServer bool `json:"syncAccountServer,omitempty"`
Claims operatorv1.OperatorClaims `json:"claims,omitempty"`
}
IssueOperatorParameters +k8s:deepcopy-gen=true
func (*IssueOperatorParameters) DeepCopy ¶
func (in *IssueOperatorParameters) DeepCopy() *IssueOperatorParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IssueOperatorParameters.
func (*IssueOperatorParameters) DeepCopyInto ¶
func (in *IssueOperatorParameters) DeepCopyInto(out *IssueOperatorParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IssueOperatorStatus ¶
type IssueOperatorStatus struct {
Operator IssueStatus `json:"operator"`
SystemAccount IssueStatus `json:"systemAccount"`
SystemAccountUser IssueStatus `json:"systemAccountUser"`
}
type IssueOperatorStorage ¶
type IssueOperatorStorage struct {
Operator string `json:"operator"`
CreateSystemAccount bool `json:"createSystemAccount"`
SyncAccountServer bool `json:"syncAccountServer"`
Claims operatorv1.OperatorClaims `json:"claims"`
}
type IssueStatus ¶
type IssueUserData ¶
type IssueUserData struct {
Operator string `json:"operator"`
Account string `json:"account"`
User string `json:"user"`
UseSigningKey string `json:"useSigningKey"`
Claims v1alpha1.UserClaims `json:"claims"`
Status IssueUserStatus `json:"status"`
}
type IssueUserParameters ¶
type IssueUserParameters struct {
Operator string `json:"operator"`
Account string `json:"account"`
User string `json:"user"`
UseSigningKey string `json:"useSigningKey,omitempty"`
Claims v1alpha1.UserClaims `json:"claims,omitempty"`
}
IssueUserParameters is the user facing interface for configuring a user issue. Using pascal case on purpose. +k8s:deepcopy-gen=true
func (*IssueUserParameters) DeepCopy ¶
func (in *IssueUserParameters) DeepCopy() *IssueUserParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IssueUserParameters.
func (*IssueUserParameters) DeepCopyInto ¶
func (in *IssueUserParameters) DeepCopyInto(out *IssueUserParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IssueUserStatus ¶
type IssueUserStatus struct {
User IssueStatus `json:"user"`
}
type IssueUserStorage ¶
type IssueUserStorage struct {
Operator string `json:"operator"`
Account string `json:"account"`
User string `json:"user"`
UseSigningKey string `json:"useSigningKey"`
Claims v1alpha1.UserClaims `json:"claims"`
Status IssueUserStatus `json:"status"`
}
type JWTData ¶
type JWTData struct {
JWTStorage
}
JWTData represents the the data returned by a JWT operation
type JWTParameters ¶
type JWTParameters struct {
Operator string `json:"operator,omitempty"`
Account string `json:"account,omitempty"`
User string `json:"user,omitempty"`
JWTStorage
}
JWTParameters represents the parameters for a JWT operation
type JWTStorage ¶
type JWTStorage struct {
JWT string `json:"jwt"`
}
JWTStorage represents a JWT stored in the backend
type NKeyStorage ¶
type NKeyStorage struct {
Seed []byte `json:"seed,omitempty"`
}
NkeySorage represents a Nkey stored in the backend
type NatsBackend ¶
natsBackend defines an object that extends the Vault backend and stores the target API's client.
type NatsClient ¶
natsClient creates an object storing the client.
type NkeyData ¶
type NkeyData struct {
PublicKey string `json:"publicKey,omitempty"`
PrivateKey string `json:"privateKey,omitempty"`
Seed string `json:"seed,omitempty"`
}
NkeyData represents the the data returned by a Nkey operation
type NkeyParameters ¶
type NkeyParameters struct {
Operator string `json:"operator,omitempty"`
Account string `json:"account,omitempty"`
Signing string `json:"signing,omitempty"`
User string `json:"user,omitempty"`
Seed string `json:"seed,omitempty"`
}
NkeyParameters represents the parameters for a Nkey operation
Source Files
¶
- backend.go
- client.go
- default.go
- errors.go
- paths_creds.go
- paths_creds_user.go
- paths_issue.go
- paths_issue_account.go
- paths_issue_operator.go
- paths_issue_user.go
- paths_jwt.go
- paths_jwt_account.go
- paths_jwt_operator.go
- paths_jwt_user.go
- paths_nkey_account.go
- paths_nkey_account_signing.go
- paths_nkey_operator.go
- paths_nkey_operator_signing.go
- paths_nkey_user.go
- paths_nkeys.go
- zz_generated.deepcopy.go
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
vault-plugin-secrets-nats
command
|
|
|
pkg
|
|
|
claims/account/v1alpha1
+k8s:deepcopy-gen=package
|
+k8s:deepcopy-gen=package |
|
claims/common
+kubebuilder:object:generate=true
|
+kubebuilder:object:generate=true |
|
claims/operator/v1alpha1
+k8s:deepcopy-gen=package
|
+k8s:deepcopy-gen=package |
|
claims/user/v1alpha1
+k8s:deepcopy-gen=package
|
+k8s:deepcopy-gen=package |
|
stm
Package stm provides methods for converting a golang struct to a map[string]interface{} and vice versa using JSON tags Therefore the name: stm -> *S*truct *T*o *M*ap
|
Package stm provides methods for converting a golang struct to a map[string]interface{} and vice versa using JSON tags Therefore the name: stm -> *S*truct *T*o *M*ap |